@@ -65,10 +65,6 @@ class PendingField(Exception):
     "Internal exception to control pending fields when using Copier."
 
 
-class CantOverrideLesson(Exception):
-    "Override a lesson is an anti-pattern and will turn your test suite very hard to understand."
-
-
 def _validate_model(model_class):
     if not is_model_class(model_class):
         raise InvalidReceiverError(model_class, 'Invalid model')
@@ -188,6 +184,50 @@ class Copier(object):
             six.reraise(InvalidCopierExpressionError, InvalidCopierExpressionError(self.expression, e), sys.exc_info()[2])
 
 
+class Mask(object):
+    '''
+    Wrapper for an expression mask that will be used to generate a random string with a custom format.
+
+    The expression mask supports 4 special characters:
+    - `#` for random numbers;
+    - `-` for random uppercase chars;
+    - `_` for random lowercase chars;
+    - `!` to escape special chars;
+
+    Other characters will not be interpreted and it will be considered part of the final string.
+
+    Example of usage: D('###.___!----') => '510.kap-NGK'
+    '''
+    def __init__(self, expression):
+        self.expression = expression
+
+    def __str__(self):
+        return "D('%s')" % self.expression
+
+    def evaluate(self):
+        import random
+        import string
+        chars = []
+        escaped = False
+        for char in self.expression:
+            if escaped:
+                c = char
+                escaped = False
+            elif char == '#':
+                c = random.choice(string.digits)
+            elif char == '-':
+                c = random.choice(string.ascii_uppercase)
+            elif char == '_':
+               c = random.choice(string.ascii_lowercase)
+            elif char == '!':
+                escaped = True
+                continue
+            else:
+                c = char
+            chars.append(c)
+        return ''.join(chars)
+
+
 class DDFLibrary(object):
     instance = None
     DEFAULT_KEY = 'ddf_default'
@@ -205,10 +245,15 @@ class DDFLibrary(object):
         return cls.instance
 
     def add_configuration(self, model_class, kwargs, name=None):
+        import os
+        import warnings
         if name in [None, True]:
             name = self.DEFAULT_KEY
         if model_class in self.configs and name in self.configs[model_class]:
-            raise CantOverrideLesson('A lesson {} has already been saved for the model {}'.format(name, model_class))
+            if not os.getenv('DDF_SHELL_MODE'):
+                msg = "Override a lesson is an anti-pattern and will turn your test suite very hard to understand."
+                msg = 'A lesson {} has already been saved for the model {}. {}'.format(name, model_class, msg)
+                warnings.warn(msg, RuntimeWarning)
         model_class_config = self.configs.setdefault(model_class, {})
         model_class_config[name] = kwargs
 
@@ -319,6 +364,8 @@ class DynamicFixture(object):
             data = self._get_data_from_custom_dynamic_fixture(field, fixture, persist_dependencies)
         elif isinstance(fixture, Copier): # Copier (C)
             data = self._get_data_from_custom_copier(instance, field, fixture)
+        elif isinstance(fixture, Mask): # Mask (M)
+            data = fixture.evaluate()
         elif isinstance(fixture, DataFixture): # DataFixture
             data = self._get_data_from_data_fixture(field, fixture)
         elif callable(fixture): # callable with the field as parameters
@@ -630,9 +677,6 @@ class DynamicFixture(object):
         return instance
 
     def teach(self, model_class, ddf_lesson=None, **kwargs):
-        '''
-        @raise an CantOverrideLesson error if the same model/lesson were called twice.
-        '''
         library = DDFLibrary.get_instance()
         for field_name in kwargs.keys():
             if field_name in self._DDF_CONFIGS:
