@@ -1,23 +1,33 @@
 # -*- coding: utf-8 -*-
 
-from django.conf import settings
-from django.db import connection
-
 from nose.plugins import Plugin
 
 
+# http://readthedocs.org/docs/nose/en/latest/plugins/interface.html
 class Queries(Plugin):
+    "python manage.py test --with-queries"
     name = 'queries'
     _queries_by_test_methods = []
 
     def configure(self, options, conf):
-        Plugin.configure(self, options, conf)
-        connection.use_debug_cursor = True
+        """
+        Called after the command line has been parsed, with the parsed options and the config container. 
+        Here, implement any config storage or changes to state or operation that are set by command line options.
+        DO NOT return a value from this method unless you want to stop all other plugins from being configured.
+        """
+        super(Queries, self).configure(options, conf)
+        if self.enabled:
+            from django.db import connection
+            connection.use_debug_cursor = True
 
     def beforeTest(self, test):
+        "Called before the test is run (before startTest)."
+        from django.db import connection
         self.initial_amount_of_queries = len(connection.queries)
 
     def afterTest(self, test):
+        "Called after the test has been run and the result recorded (after stopTest)."
+        from django.db import connection
         self.final_amount_of_queries = len(connection.queries)
         self._queries_by_test_methods.append((test, self.final_amount_of_queries - self.initial_amount_of_queries))
 
